searchData={"items":[{"type":"task","title":"mix proto.gen","doc":"Mix task for downloading and compiling flagd protobuf definitions.\n\nThis task:\n\n  1. Downloads the `evaluation.proto` and `sync.proto` files from the official\n     flagd Buf registry.\n  2. Saves them to `priv/protos/`.\n  3. Runs `protoc` to generate Elixir + gRPC modules into\n     `lib/openfeature/provider/flagd/proto/`.","ref":"Mix.Tasks.Proto.Gen.html"},{"type":"task","title":"Usage - mix proto.gen","doc":"Run the following from the root of the project:\n\n    mix proto.gen\n\nThis is primarily intended for development workflows until `buf` supports Elixir\nas a target. Generated modules are checked in and used by the Flagd provider.","ref":"Mix.Tasks.Proto.Gen.html#module-usage"},{"type":"module","title":"OpenFeature.Provider.Flagd.GRPC","doc":"OpenFeature provider for flagd that communicates with a `flagd` instance over gRPC.\n\nThis is a remote flagd provider that uses the gRPC evaluation API to resolve flag values.","ref":"OpenFeature.Provider.Flagd.GRPC.html"},{"type":"function","title":"OpenFeature.Provider.Flagd.GRPC.new/1","doc":"Creates a new flagd gRPC provider.","ref":"OpenFeature.Provider.Flagd.GRPC.html#new/1"},{"type":"function","title":"Options - OpenFeature.Provider.Flagd.GRPC.new/1","doc":"* `:host` - The hostname or IP address of the flagd instance (default: `\"localhost\"`)\n  * `:port` - The port number (default: `8013`)\n  * `:tls` - Whether to use TLS for connections (default: `false`)\n  * `:cacertfile` - (optional) Path to a custom TLS certificate file\n  * `:cacerts` - (optional) CA certificates as PEM-encoded binaries\n  * `:name` - (optional) Custom name for the provider (default: `\"FlagdGRPC\"`)\n  * `:domain` - (optional) Domain name to differentiate between providers\n  * `:hooks` - (optional) A list of OpenFeature hooks (%OpenFeature.Hook{})","ref":"OpenFeature.Provider.Flagd.GRPC.html#new/1-options"},{"type":"function","title":"Examples - OpenFeature.Provider.Flagd.GRPC.new/1","doc":"```elixir\n# Simple usage with defaults\nprovider = OpenFeature.Provider.Flagd.GRPC.new()\n\n# With custom options\nprovider = OpenFeature.Provider.Flagd.GRPC.new(port: 8013, domain: \"my-service\")\n\n# With TLS enabled\nprovider = OpenFeature.Provider.Flagd.GRPC.new(\n  host: \"flagd.example.com\",\n  tls: true,\n  cacertfile: \"/path/to/cert.pem\"\n)\n```","ref":"OpenFeature.Provider.Flagd.GRPC.html#new/1-examples"},{"type":"type","title":"OpenFeature.Provider.Flagd.GRPC.t/0","doc":"GRPC provider for flagd","ref":"OpenFeature.Provider.Flagd.GRPC.html#t:t/0"},{"type":"module","title":"OpenFeature.Provider.Flagd.GRPC.EventStream","doc":"Handles gRPC event streaming for the Flagd provider.\n\nThis module listens for lifecycle events from `flagd` (such as `provider_ready` and\n`configuration_change`) and emits them via `OpenFeature.EventEmitter`.\n\nThis module is a `GenServer` and should be added to your supervision tree.","ref":"OpenFeature.Provider.Flagd.GRPC.EventStream.html"},{"type":"module","title":"Static Supervision Example - OpenFeature.Provider.Flagd.GRPC.EventStream","doc":"# In your Application module\n    client = OpenFeature.get_client(\"gRPC\")\n\n    children = [\n      {OpenFeature.Provider.Flagd.GRPC.EventStream, client}\n    ]\n\n    Supervisor.start_link(children, strategy: :one_for_one)","ref":"OpenFeature.Provider.Flagd.GRPC.EventStream.html#module-static-supervision-example"},{"type":"module","title":"Dynamic Supervision Example - OpenFeature.Provider.Flagd.GRPC.EventStream","doc":"# In your Application module\n    children = [\n      {DynamicSupervisor, name: MyApp.EventStreamSupervisor, strategy: :one_for_one}\n    ]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n\n    # Later at runtime\n    client = OpenFeature.get_client(\"gRPC\")\n\n    DynamicSupervisor.start_child(MyApp.EventStreamSupervisor, {OpenFeature.Provider.Flagd.GRPC.EventStream, client})","ref":"OpenFeature.Provider.Flagd.GRPC.EventStream.html#module-dynamic-supervision-example"},{"type":"function","title":"OpenFeature.Provider.Flagd.GRPC.EventStream.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OpenFeature.Provider.Flagd.GRPC.EventStream.html#child_spec/1"},{"type":"function","title":"OpenFeature.Provider.Flagd.GRPC.EventStream.start_link/1","doc":"","ref":"OpenFeature.Provider.Flagd.GRPC.EventStream.html#start_link/1"},{"type":"module","title":"OpenFeature.Provider.Flagd.HTTP","doc":"OpenFeature provider for flagd that communicates with a `flagd` instance over HTTP.\n\nThis is a remote flagd provider that uses the HTTP evaluation API (JSON) to resolve flag values.","ref":"OpenFeature.Provider.Flagd.HTTP.html"},{"type":"function","title":"OpenFeature.Provider.Flagd.HTTP.new/1","doc":"Creates a new flagd HTTP provider.","ref":"OpenFeature.Provider.Flagd.HTTP.html#new/1"},{"type":"function","title":"Options - OpenFeature.Provider.Flagd.HTTP.new/1","doc":"* `:scheme` - The URL scheme (default: `\"http\"`)\n  * `:host` - The hostname or IP address of the flagd instance (default: `\"localhost\"`)\n  * `:port` - The port number (default: `8013`)\n  * `:name` - (optional) Custom name for the provider (default: `\"FlagdHTTP\"`)\n  * `:domain` - (optional) Domain name to differentiate between providers\n  * `:hooks` - (optional) A list of OpenFeature hooks (%OpenFeature.Hook{})\n  * `:req_opts` - (optional) Keyword list passed to `Req.new/1`","ref":"OpenFeature.Provider.Flagd.HTTP.html#new/1-options"},{"type":"function","title":"Examples - OpenFeature.Provider.Flagd.HTTP.new/1","doc":"```elixir\n# Simple usage with defaults\nprovider = OpenFeature.Provider.Flagd.HTTP.new()\n\n# With custom options\nprovider = OpenFeature.Provider.Flagd.HTTP.new(port: 8013, domain: \"my-service\")\n\n# With HTTPS\nprovider = OpenFeature.Provider.Flagd.HTTP.new(scheme: \"https\", host: \"flagd.example.com\")\n```","ref":"OpenFeature.Provider.Flagd.HTTP.html#new/1-examples"},{"type":"type","title":"OpenFeature.Provider.Flagd.HTTP.t/0","doc":"HTTP provider for flagd","ref":"OpenFeature.Provider.Flagd.HTTP.html#t:t/0"},{"type":"module","title":"OpenFeature.Provider.Flagd.Reason","doc":"Converts string reasons from flagd into OpenFeature reason atoms.","ref":"OpenFeature.Provider.Flagd.Reason.html"},{"type":"function","title":"OpenFeature.Provider.Flagd.Reason.to_reason/1","doc":"","ref":"OpenFeature.Provider.Flagd.Reason.html#to_reason/1"},{"type":"extras","title":"Flagd Provider for OpenFeature","doc":"# Flagd Provider for OpenFeature\n\nAn OpenFeature provider for `flagd`, enabling feature flag evaluation in Elixir using gRPC or HTTP.\n\nThis library integrates with the OpenFeature SDK for Elixir and supports remote evaluation via `flagd` using gRPC or HTTP.","ref":"readme.html"},{"type":"extras","title":"Installation - Flagd Provider for OpenFeature","doc":"Add `open_feature_flagd_provider` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:open_feature_provider_flagd, \"~> 0.1.0\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Providers - Flagd Provider for OpenFeature","doc":"This library supports:\n\n- `OpenFeature.Provider.Flagd.HTTP`\n- `OpenFeature.Provider.Flagd.GRPC`\n\nAll providers implement the `OpenFeature.Provider` behaviour and can be used with the OpenFeature SDK. This means you can swap between providers (e.g. `gRPC` or `HTTP`) with no changes to your application code beyond provider initialization.","ref":"readme.html#providers"},{"type":"extras","title":"Usage - Flagd Provider for OpenFeature","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"gRPC Provider - Flagd Provider for OpenFeature","doc":"```elixir\n# Simple usage with defaults\nprovider = OpenFeature.Provider.Flagd.GRPC.new()\n\n# With custom options\nprovider = OpenFeature.Provider.Flagd.GRPC.new(\n  host: \"flagd.example.com\",\n  port: 8013,\n  tls: true,\n  cacertfile: \"/path/to/cert.pem\"\n)\n\n{:ok, _} = OpenFeature.set_provider(provider)\nclient = OpenFeature.get_client()\nOpenFeature.Client.get_boolean_value(client, \"my-feature\", false)\n```","ref":"readme.html#grpc-provider"},{"type":"extras","title":"Event Streaming - Flagd Provider for OpenFeature","doc":"The gRPC provider supports event streaming via the EventStream module. This allows your application to receive `:ready` and `:configuration_changed` events from flagd.\n\nTo enable streaming, you must start the stream manually using `OpenFeature.Provider.Flagd.GRPC.EventStream.start_link(client)`. The stream runs as a long-lived `GenServer` and should be supervised using either static or dynamic supervision, depending on your needs.\n\nFor setup examples and supervision options, see the `EventStream` module documentation.","ref":"readme.html#event-streaming"},{"type":"extras","title":"HTTP Provider - Flagd Provider for OpenFeature","doc":"```elixir\n# Simple usage with defaults\nprovider = OpenFeature.Provider.Flagd.HTTP.new()\n\n# With custom options\nprovider = OpenFeature.Provider.Flagd.HTTP.new(\n  scheme: \"https\",\n  host: \"flagd.example.com\",\n  port: 8013\n)\n\n{:ok, _} = OpenFeature.set_provider(provider)\nclient = OpenFeature.get_client()\nOpenFeature.Client.get_boolean_value(client, \"my-feature\", false)\n```","ref":"readme.html#http-provider"},{"type":"extras","title":"Regenerating gRPC Protos (Development Only) - Flagd Provider for OpenFeature","doc":"This project includes a mix task to download and generate Elixir modules from the latest [`flagd`](https://buf.build/open-feature/flagd) protobuf definitions.\n\nTo regenerate:\n\n```sh\nmix proto.gen\n```\n\n> [!NOTE]\n> You must have both `protoc` and `protoc-gen-elixir` available in your system `PATH` for this task to work. See the [official docs](https://hexdocs.pm/protobuf/readme.html#generate-elixir-code) for installation instructions.","ref":"readme.html#regenerating-grpc-protos-development-only"},{"type":"extras","title":"Roadmap - Flagd Provider for OpenFeature","doc":"- [ ] Cache resolution details\n- [ ] In-process provider using the flagd sync protocol","ref":"readme.html#roadmap"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"},{"type":"extras","title":"Contributing to OpenFeature","doc":"# Contributing to OpenFeature\n\n[![Sign-up](https://img.shields.io/static/v1?label=Sign-up&message=for%20news&color=blue)](https://bit.ly/openfeature-signup)\n[![a](https://img.shields.io/badge/slack-%40cncf%2Fopenfeature-brightgreen?style=flat&logo=slack)](https://cloud-native.slack.com/archives/C0344AANLA1)\n[![Roadmap](https://img.shields.io/static/v1?label=Roadmap&message=public&color=green)](https://github.com/orgs/open-feature/projects/1)\n[![Governance](https://img.shields.io/static/v1?label=Governance&message=bootstrap&color=yellow)](https://github.com/open-feature/governance)\n[![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/open-feature/.github/blob/main/CODE_OF_CONDUCT.md)","ref":"contributing.html"},{"type":"extras","title":"Contacting us - Contributing to OpenFeature","doc":"We hold regular meetings which you can see [here](https://github.com/open-feature/community/#meetings-and-events).\n\nWe are also present on the `#openfeature` channel in the [CNCF slack](https://slack.cncf.io/).","ref":"contributing.html#contacting-us"},{"type":"extras","title":"Contributor ladder - Contributing to OpenFeature","doc":"Are you interested in contributing on a regular basis?\nCheck out our [contributor ladder](https://openfeature.dev/community/CONTRIBUTOR_LADDER).","ref":"contributing.html#contributor-ladder"},{"type":"extras","title":"Project governance - Contributing to OpenFeature","doc":"Project governance is documented [here](https://github.com/open-feature/community/blob/main/technical-guidelines.md#repository-requirements).","ref":"contributing.html#project-governance"},{"type":"extras","title":"Repository requirements - Contributing to OpenFeature","doc":"Repository requirements are documented [here](https://github.com/open-feature/community/blob/main/governance-charter.md).","ref":"contributing.html#repository-requirements"},{"type":"extras","title":"Developer Certificate Of Origin - Contributing to OpenFeature","doc":"See [Developer Certificate Of Origin](https://github.com/open-feature/community/blob/main/technical-guidelines.md#developer-certificate-of-origin)","ref":"contributing.html#developer-certificate-of-origin"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [0.1.0](https://github.com/open-feature/elixir-sdk-contrib/compare/openfeature-provider-flagd/v0.1.0...openfeature-provider-flagd/v0.1.0) (2025-04-22)","ref":"changelog.html"},{"type":"extras","title":"✨ New Features - Changelog","doc":"* add flagd provider for HTTP and GRPC ([2e4a499](https://github.com/open-feature/elixir-sdk-contrib/commit/2e4a4998ec2650a0775c991493470f98eb0d4e19))","ref":"changelog.html#new-features"},{"type":"extras","title":"🧹 Chore - Changelog","doc":"* github actions setup ([#2](https://github.com/open-feature/elixir-sdk-contrib/issues/2)) ([88bb11e](https://github.com/open-feature/elixir-sdk-contrib/commit/88bb11e9487fe1d815b0845b03f808f588274f9c))\n* grant issues: write perm to release-please ([f1437f2](https://github.com/open-feature/elixir-sdk-contrib/commit/f1437f2e49283f1cae722be6aaec0badf3b3fcd5))\n* **main:** release openfeature-provider-flagd 0.1.0 ([#3](https://github.com/open-feature/elixir-sdk-contrib/issues/3)) ([1ff679c](https://github.com/open-feature/elixir-sdk-contrib/commit/1ff679c74f0198300052a315315a16bd474dcb50))\n* remove cached .DS_Store ([5f12d00](https://github.com/open-feature/elixir-sdk-contrib/commit/5f12d0088b4f0a4ff2f078d4df97a14a182a8b89))\n\n## [0.1.0](https://github.com/open-feature/elixir-sdk-contrib/compare/openfeature-provider-flagd/v0.1.0...openfeature-provider-flagd/v0.1.0) (2025-04-18)","ref":"changelog.html#chore"},{"type":"extras","title":"✨ New Features - Changelog","doc":"* add flagd provider for HTTP and GRPC ([2e4a499](https://github.com/open-feature/elixir-sdk-contrib/commit/2e4a4998ec2650a0775c991493470f98eb0d4e19))","ref":"changelog.html#new-features"},{"type":"extras","title":"🧹 Chore - Changelog","doc":"* github actions setup ([#2](https://github.com/open-feature/elixir-sdk-contrib/issues/2)) ([88bb11e](https://github.com/open-feature/elixir-sdk-contrib/commit/88bb11e9487fe1d815b0845b03f808f588274f9c))\n* grant issues: write perm to release-please ([f1437f2](https://github.com/open-feature/elixir-sdk-contrib/commit/f1437f2e49283f1cae722be6aaec0badf3b3fcd5))\n* remove cached .DS_Store ([5f12d00](https://github.com/open-feature/elixir-sdk-contrib/commit/5f12d0088b4f0a4ff2f078d4df97a14a182a8b89))","ref":"changelog.html#chore"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}